==> cctools_7.1.2.orig.tar.xz: cctools-7.1.2/doc/manuals/man_pages.md <==
# Man Pages

These pages contain a brief synopsis of every command,
for reference purposes.  Please see the user manuals
for a broader discussion of how each tool is used.

## Makeflow

  * [makeflow(1)](man_pages/makeflow.md)
  * [makeflow_status(1)](man_pages/makeflow_status.md)
  * [makeflow_monitor(1)](man_pages/makeflow_monitor.md)
  * [makeflow_linker(1)](man_pages/makeflow_linker.md)
  * [makeflow_analyze(1)](man_pages/makeflow_analyze.md)
  * [makeflow_viz(1)](man_pages/makeflow_viz.md)
  * [makeflow_graph_log(1)](man_pages/makeflow_graph_log.md)
  * [starch(1)](man_pages/starch.md)
  * [makeflow_ec2_setup(1)](man_pages/makeflow_ec2_setup.md)
  * [makeflow_ec2_cleanup(1)](man_pages/makeflow_ec2_cleanup.md)
  * [condor_submit_makeflow(1)](man_pages/condor_submit_makeflow.md)

## Work Queue

  * [work_queue_worker(1)](man_pages/work_queue_worker.md)
  * [work_queue_status(1)](man_pages/work_queue_status.md)
  * [work_queue_graph_log(1)](man_pages/work_queue_graph_log.md)
  * [work_queue_factory(1)](man_pages/work_queue_factory.md)

### Worker Submission Scripts

  * [condor_submit_workers(1)](man_pages/condor_submit_workers.md)
  * [sge_submit_workers(1)](man_pages/sge_submit_workers.md)
  * [pbs_submit_workers(1)](man_pages/pbs_submit_workers.md)
  * [torque_submit_workers(1)](man_pages/torque_submit_workers.md)
  * [slurm_submit_workers(1)](man_pages/slurm_submit_workers.md)

## Resource Monitor

  * [resource_monitor(1)](man_pages/resource_monitor.md)
  * [resource_monitor_histograms(1)](man_pages/resource_monitor_histograms.md)
  * [resource_monitor_visualizer(1)](man_pages/resource_monitor_visualizer.md)

## Catalog Server

  * [catalog_server(1)](man_pages/catalog_server.md)
  * [catalog_update(1)](man_pages/catalog_update.md)
  * [catalog_query(1)](man_pages/catalog_query.md)
  * [deltadb_query(1)](man_pages/deltadb_query.md)

## Parrot

  * [parrot_run(1)](man_pages/parrot_run.md)
  * [parrot_cp(1)](man_pages/parrot_cp.md)
  * [parrot_md5(1)](man_pages/parrot_md5.md)
  * [parrot_getacl(1)](man_pages/parrot_getacl.md)
  * [parrot_setacl(1)](man_pages/parrot_setacl.md)
  * [parrot_mkalloc(1)](man_pages/parrot_mkalloc.md)
  * [parrot_lsalloc(1)](man_pages/parrot_lsalloc.md)
  * [parrot_locate(1)](man_pages/parrot_locate.md)
  * [parrot_timeout(1)](man_pages/parrot_timeout.md)
  * [parrot_whoami(1)](man_pages/parrot_whoami.md)
  * [parrot_package_create(1)](man_pages/parrot_package_create.md)
  * [parrot_package_run(1)](man_pages/parrot_package_run.md)
  * [chroot_package_run(1)](man_pages/chroot_package_run.md)
  * [parrot_mount(1)](man_pages/parrot_mount.md)
  * [parrot_namespace(1)](man_pages/parrot_namespace.md)

## Chirp File System
 
  * [chirp(1)](man_pages/chirp.md)
  * [chirp_status(1)](man_pages/chirp_status.md)
  * [chirp_fuse(1)](man_pages/chirp_fuse.md)
  * [chirp_get(1)](man_pages/chirp_get.md)
  * [chirp_put(1)](man_pages/chirp_put.md)
  * [chirp_stream_files(1)](man_pages/chirp_stream_files.md)
  * [chirp_distribute(1)](man_pages/chirp_distribute.md)
  * [chirp_benchmark(1)](man_pages/chirp_benchmark.md)
  * [chirp_server(1)](man_pages/chirp_server.md)
  * [chirp_server_hdfs(1)](man_pages/chirp_server_hdfs.md)
  * [The Chirp Protocol](chirp/chirp_protocol.md)

## Confuga File System

  * [confuga(1)](man_pages/confuga.md)

==> cctools_7.14.5.orig.tar.xz: cctools-7.14.5/doc/manuals/man_pages.md <==
# Man Pages

These pages contain a brief synopsis of every command,
for reference purposes.  Please see the user manuals
for a broader discussion of how each tool is used.

## Makeflow

  * [makeflow(1)](man_pages/makeflow.md)
  * [makeflow_status(1)](man_pages/makeflow_status.md)
  * [makeflow_monitor(1)](man_pages/makeflow_monitor.md)
  * [makeflow_linker(1)](man_pages/makeflow_linker.md)
  * [makeflow_analyze(1)](man_pages/makeflow_analyze.md)
  * [makeflow_viz(1)](man_pages/makeflow_viz.md)
  * [makeflow_graph_log(1)](man_pages/makeflow_graph_log.md)
  * [starch(1)](man_pages/starch.md)
  * [makeflow_ec2_setup(1)](man_pages/makeflow_ec2_setup.md)
  * [makeflow_ec2_cleanup(1)](man_pages/makeflow_ec2_cleanup.md)
  * [condor_submit_makeflow(1)](man_pages/condor_submit_makeflow.md)

## TaskVine

  * [vine_worker(1)](man_pages/vine_worker.md)
  * [vine_status(1)](man_pages/vine_status.md)
  * [vine_graph_log(1)](man_pages/vine_graph_log.md)
  * [vine_factory(1)](man_pages/work_queue_factory.md)

## Work Queue

  * [work_queue_worker(1)](man_pages/work_queue_worker.md)
  * [work_queue_status(1)](man_pages/work_queue_status.md)
  * [work_queue_graph_log(1)](man_pages/work_queue_graph_log.md)
  * [work_queue_factory(1)](man_pages/work_queue_factory.md)

### Worker Submission Scripts

  * [condor_submit_workers(1)](man_pages/condor_submit_workers.md)
  * [sge_submit_workers(1)](man_pages/sge_submit_workers.md)
  * [pbs_submit_workers(1)](man_pages/pbs_submit_workers.md)
  * [torque_submit_workers(1)](man_pages/torque_submit_workers.md)
  * [slurm_submit_workers(1)](man_pages/slurm_submit_workers.md)

## Resource Monitor

  * [resource_monitor(1)](man_pages/resource_monitor.md)

## PONCHO Package Management

  * [poncho_package_create(1)](man_pages/poncho_package_create.md)
  * [poncho_package_run(1)](man_pages/poncho_package_run.md)
  * [poncho_package_analyze(1)](man_pages/poncho_package_analyze.md)

## Catalog Server

  * [catalog_server(1)](man_pages/catalog_server.md)
  * [catalog_update(1)](man_pages/catalog_update.md)
  * [catalog_query(1)](man_pages/catalog_query.md)
  * [deltadb_query(1)](man_pages/deltadb_query.md)

## Parrot

  * [parrot_run(1)](man_pages/parrot_run.md)
  * [parrot_cp(1)](man_pages/parrot_cp.md)
  * [parrot_md5(1)](man_pages/parrot_md5.md)
  * [parrot_getacl(1)](man_pages/parrot_getacl.md)
  * [parrot_setacl(1)](man_pages/parrot_setacl.md)
  * [parrot_mkalloc(1)](man_pages/parrot_mkalloc.md)
  * [parrot_lsalloc(1)](man_pages/parrot_lsalloc.md)
  * [parrot_locate(1)](man_pages/parrot_locate.md)
  * [parrot_timeout(1)](man_pages/parrot_timeout.md)
  * [parrot_whoami(1)](man_pages/parrot_whoami.md)
  * [parrot_package_create(1)](man_pages/parrot_package_create.md)
  * [parrot_package_run(1)](man_pages/parrot_package_run.md)
  * [chroot_package_run(1)](man_pages/chroot_package_run.md)
  * [parrot_mount(1)](man_pages/parrot_mount.md)
  * [parrot_namespace(1)](man_pages/parrot_namespace.md)

## Chirp File System
 
  * [chirp(1)](man_pages/chirp.md)
  * [chirp_status(1)](man_pages/chirp_status.md)
  * [chirp_fuse(1)](man_pages/chirp_fuse.md)
  * [chirp_get(1)](man_pages/chirp_get.md)
  * [chirp_put(1)](man_pages/chirp_put.md)
  * [chirp_stream_files(1)](man_pages/chirp_stream_files.md)
  * [chirp_distribute(1)](man_pages/chirp_distribute.md)
  * [chirp_benchmark(1)](man_pages/chirp_benchmark.md)
  * [chirp_server(1)](man_pages/chirp_server.md)
  * [chirp_server_hdfs(1)](man_pages/chirp_server_hdfs.md)
  * [The Chirp Protocol](chirp/chirp_protocol.md)

## Confuga File System

  * [confuga(1)](man_pages/confuga.md)
